import 'dart:io';

import 'package:dio/dio.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:get/get.dart' hide FormData;
import 'package:get_storage/get_storage.dart';

class DioService {
  GetStorage box = GetStorage();
  static String surl = '';
  Dio dio = new Dio(BaseOptions(headers: {
    HttpHeaders.authorizationHeader: "Bearer ${GetStorage().read("token")}",
  }, baseUrl: surl));

  Future getData(String url,
      {String errorMessage = "Oops something went wrong"}) async {
    try {
      final response = await dio.get(
        url,
      );
      if (response.data["success"] && response.data['data'] != null) {
        return response.data;
      } else {
        return null;
      }
    } catch (e) {
      print(e);
      if (e is DioError) {
        if (e.type == DioErrorType.connectTimeout) {
          Get.rawSnackbar(
              message:
                  "Internet unavailable. Please check your internet connection.");
        }
      }
      return null;
    }
  }

  Future postData(String url, Map data,
      {String errorMessage = "Oops something went wrong",
      String expect = "Json"}) async {
    String token = "";
    try {
      token = (FirebaseAuth.instance.currentUser != null)
          ? await FirebaseAuth.instance.currentUser!.getIdToken()
          : "";
    } catch (e) {}

    dio = new Dio(
      BaseOptions(
        headers: {
          HttpHeaders.authorizationHeader: "Bearer ${token}",
        },
        baseUrl: surl,
      ),
    );

    try {
      print(data);
      print(url);
      final response = await dio.post(url, data: data);
      print(url);

      if (response.statusCode == 200 || response.statusCode == 201) {
        if (expect == "Json")
          return response.data;
        else if (expect == "List")
          return response.data as List;
        else
          return response.data as Map;
      }

      // if (response.data["success"] && response.data['data'] != null) {
      //   return response.data;
      // } else {
      //   return null;
      // }
    } catch (e) {
      if (e is DioError) {
        if (e.type == DioErrorType.connectTimeout) {
          Get.rawSnackbar(
              message:
                  "Internet unavailable. Please check your internet connection.");
        } else {
          Get.rawSnackbar(message: errorMessage);
        }
      } else {
        Get.rawSnackbar(message: errorMessage);
      }
      print(e.toString());
      // Fluttertoast.showToast(
      //   // msg: e.toString(),
      //   msg: 'Error: Something went wrong',
      //   backgroundColor: Colors.red,
      //   webBgColor: "red",
      // );
      return null;
    }
  }

  Future postFormData(String url, FormData data,
      {String errorMessage = "Oops something went wrong"}) async {
    try {
      final response = await dio.post(
        url,
        data: data,
      );
      if (response.data["success"] && response.data['data'] != null) {
        return response.data;
      } else {
        return null;
      }
    } catch (e) {
      if (e is DioError) {
        if (e.type == DioErrorType.connectTimeout) {
          Get.rawSnackbar(
              message:
                  "Internet unavailable. Please check your internet connection.");
        } else {
          Get.rawSnackbar(message: errorMessage);
        }
      } else {
        Get.rawSnackbar(message: errorMessage);
      }
      return null;
    }
  }

  Future patchData(String url, Map data,
      {String errorMessage = "Oops something went wrong"}) async {
    try {
      final response = await dio.patch(url, data: data);
      if (response.data["success"] && response.data['data'] != null) {
        return response.data;
      } else {
        return null;
      }
    } catch (e) {
      if (e is DioError) {
        if (e.type == DioErrorType.connectTimeout) {
          Get.rawSnackbar(
              message:
                  "Internet unavailable. Please check your internet connection.");
        } else {
          Get.rawSnackbar(message: errorMessage);
        }
      } else {
        Get.rawSnackbar(message: errorMessage);
      }
      return null;
    }
  }

  Future patchFormData(String url, FormData data,
      {String errorMessage = "Oops something went wrong"}) async {
    try {
      final response = await dio.patch(
        url,
        data: data,
      );
      if (response.data["success"] && response.data['data'] != null) {
        return response.data;
      } else {
        return null;
      }
    } catch (e) {
      if (e is DioError) {
        if (e.type == DioErrorType.connectTimeout) {
          Get.rawSnackbar(
              message:
                  "Internet unavailable. Please check your internet connection.");
        } else {
          Get.rawSnackbar(message: errorMessage);
        }
      } else {
        Get.rawSnackbar(message: errorMessage);
      }
      return null;
    }
  }

  Future deleteData(String url,
      {Map data = const {},
      String errorMessage = "Oops something went wrong"}) async {
    try {
      final response = await dio.delete(url, data: data);
      if (response.data["success"] && response.data['data'] != null) {
        return response.data;
      } else {
        return null;
      }
    } catch (e) {
      if (e is DioError) {
        if (e.type == DioErrorType.connectTimeout) {
          Get.rawSnackbar(
              message:
                  "Internet unavailable. Please check your internet connection.");
        } else {
          Get.rawSnackbar(message: errorMessage);
        }
      } else {
        Get.rawSnackbar(message: errorMessage);
      }
      return null;
    }
  }
}
