import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:google_fonts/google_fonts.dart';

Widget CustomTextField({
  final String? hintText,
  //String label,
  final IconData? prefixIcon,
  final IconData? suffixIcon,
  final TextEditingController? controller,
  final TextInputType keyboardType = TextInputType.text,
  final TextInputAction textInputAction = TextInputAction.next,
  final double iconSize = 17,
  // String fontFamily = 'Roboto-Light.ttf',
  final double fontSize = 17,
  final double? letterSpacing = null,
  final FontWeight fontWeight = FontWeight.w400,
  final bool readOnly = false,
  final String? labelText,
  // String validationType = 'all',
  final Function? validator,
  final double horizontalPadding = 12,
  final double? verticalPadding,
  Function(String value)? onChange,
  final List<TextInputFormatter>? inputFormatters,
  final MaxLengthEnforcement? maxLengthEnforcement,
  final int? maxLength,
}) {
  return Container(
    child: TextField(
      style: GoogleFonts.roboto(
        fontWeight: fontWeight,
        letterSpacing: letterSpacing,
        color: Colors.black87,
        fontSize: fontSize,
      ),
      readOnly: readOnly,
      controller: controller,
      showCursor: true,
      autofocus: false,
      keyboardType: keyboardType,
      // onChanged: onChange,
      textInputAction: textInputAction,
      decoration: InputDecoration(
        counterText: "",
        border: OutlineInputBorder(
          borderRadius: BorderRadius.all(Radius.circular(10.0)),
          borderSide: BorderSide(
            width: 0,
            style: BorderStyle.none,
          ),
        ),
        isDense: true,
        contentPadding: EdgeInsets.only(
          left: horizontalPadding,
          right: horizontalPadding,
          top: verticalPadding ?? 24,
          bottom: verticalPadding ?? 16,
        ),
        filled: true,
        prefixIcon: (prefixIcon != null)
            ? Icon(
                prefixIcon,
                color: Color(0xFF666666),
                size: iconSize,
              )
            : null,
        suffixIcon: (suffixIcon != null)
            ? Icon(
                suffixIcon,
                color: Color(0xFF666666),
                size: iconSize,
              )
            : null,
        fillColor: Color(0xFFF2F3F5),
        hintStyle: GoogleFonts.roboto(
          letterSpacing: letterSpacing,

          color: Color(0xFF666666),
          // fontFamily: fontFamily,
          fontWeight: fontWeight,
          fontSize: fontSize,
        ),
        labelText: labelText,
        labelStyle: GoogleFonts.roboto(
          letterSpacing: letterSpacing,
          color: Colors.grey[800],
          fontWeight: fontWeight,
        ),
        errorText: validator != null ? validator(controller?.text) : null,
        hintText: hintText,
      ),
      inputFormatters: inputFormatters,
      maxLengthEnforcement: maxLengthEnforcement,
      maxLength: maxLength,
    ),
  );
}

Widget CustomCheckoutTextField({
  String? hintText,

  //String label,
  IconData? prefixIcon,
  IconData? suffixIcon,
  TextEditingController? controller,
  TextInputType keyboardType = TextInputType.text,
  TextInputAction textInputAction = TextInputAction.next,
  double iconSize = 17,
  double fontSize = 14,
  FontWeight fontWeight = FontWeight.w400,
  bool readOnly = false,
  double? letterSpacing = null,
  String? labelText,
  final List<TextInputFormatter>? inputFormatters,
  final MaxLengthEnforcement? maxLengthEnforcement,
  final int? maxLength,
  final String? Function(String?)? validator,
}) {
  return Container(
    child: TextFormField(
      style: GoogleFonts.roboto(
        fontWeight: fontWeight,
        letterSpacing: letterSpacing,
        color: Colors.grey[800],
      ),
      readOnly: readOnly,
      controller: controller,
      showCursor: true,
      autofocus: false,
      keyboardType: keyboardType,
      textInputAction: textInputAction,
      decoration: InputDecoration(
        counterText: "",
        border: OutlineInputBorder(
          borderRadius: BorderRadius.all(Radius.circular(0.0)),
          borderSide: BorderSide(
            width: 0,
            style: BorderStyle.none,
          ),
        ),
        filled: true,
        prefixIcon: (prefixIcon != null)
            ? Icon(
                prefixIcon,
                color: Color(0xFF666666),
                size: iconSize,
              )
            : null,
        suffixIcon: (suffixIcon != null)
            ? Icon(
                suffixIcon,
                color: Color(0xFF666666),
                size: iconSize,
              )
            : null,
        fillColor: Color(0xFFF2F3F5),
        hintStyle: GoogleFonts.roboto(
          fontWeight: fontWeight,
          letterSpacing: letterSpacing,
          color: Color(0xFF666666),
          fontSize: fontSize,
        ),
        labelText: labelText,
        labelStyle: GoogleFonts.roboto(
          fontWeight: fontWeight,
          letterSpacing: letterSpacing,
          color: Colors.grey[800],
        ),
        hintText: hintText,
      ),
      inputFormatters: inputFormatters,
      validator: validator,
      maxLengthEnforcement: maxLengthEnforcement,
      maxLength: maxLength,
    ),
  );
}

Widget CustomTextFormField({
  final String? hintText,
  //String label,
  final IconData? prefixIcon,
  final IconData? suffixIcon,
  final TextEditingController? controller,
  final TextInputType keyboardType = TextInputType.text,
  final TextInputAction textInputAction = TextInputAction.next,
  final double iconSize = 17,
  // String fontFamily = 'Roboto-Light.ttf',
  final double fontSize = 17,
  final double? letterSpacing = null,
  final FontWeight fontWeight = FontWeight.w400,
  final bool readOnly = false,
  final String? labelText,
  // String validationType = 'all',
  final String? Function(String?)? validator,
  final double? horizontalPadding = 12,
  final double? verticalPadding,
  Function(String value)? onChange,
  final List<TextInputFormatter>? inputFormatters,
  final MaxLengthEnforcement? maxLengthEnforcement,
  final int? maxLength,
  final bool obscureText = false,
}) {
  return Container(
    child: TextFormField(
      style: GoogleFonts.roboto(
        fontWeight: fontWeight,
        letterSpacing: letterSpacing,
        color: Colors.black87,
        fontSize: fontSize,
      ),
      readOnly: readOnly,
      controller: controller,
      showCursor: true,
      autofocus: false,
      keyboardType: keyboardType,
      // onChanged: onChange,
      textInputAction: textInputAction,
      decoration: InputDecoration(
        border: const OutlineInputBorder(
          borderRadius: BorderRadius.all(Radius.circular(10.0)),
          borderSide: BorderSide(
            width: 0,
            style: BorderStyle.none,
          ),
        ),
        isDense: true,
        contentPadding: EdgeInsets.only(
          left: horizontalPadding ?? 0,
          right: horizontalPadding ?? 0,
          top: verticalPadding ?? 24,
          bottom: verticalPadding ?? 16,
        ),
        filled: true,
        prefixIcon: (prefixIcon != null)
            ? Icon(
                prefixIcon,
                color: Color(0xFF666666),
                size: iconSize,
              )
            : null,
        suffixIcon: (suffixIcon != null)
            ? Icon(
                suffixIcon,
                color: Color(0xFF666666),
                size: iconSize,
              )
            : null,
        fillColor: Color(0xFFF2F3F5),
        hintStyle: GoogleFonts.roboto(
          letterSpacing: letterSpacing,
          color: Color(0xFF666666),
          fontWeight: fontWeight,
          fontSize: fontSize,
        ),
        labelText: labelText,
        labelStyle: GoogleFonts.roboto(
          letterSpacing: letterSpacing,
          color: Colors.grey[800],
          fontWeight: fontWeight,
        ),
        hintText: hintText,
        counterText: "",
      ),
      inputFormatters: inputFormatters,
      validator: validator,
      maxLengthEnforcement: maxLengthEnforcement,
      maxLength: maxLength,
      obscureText: obscureText,
    ),
  );
}
