import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

class CustomTextFormField extends StatelessWidget {
  final Widget icon;
  final Color iconColor;
  final Color backgroundColor;
  final String hintText;
  final TextStyle? hintTextStyle;
  final TextEditingController controller;
  final FormFieldValidator<String>? validator;
  final ValueChanged<String>? onChanged;
  final bool obscureText;
  final Widget? suffixIcon;
  final double? width;
  final double? height;
  final double borderRadius;

  const CustomTextFormField({
    Key? key,
    required this.icon,
    required this.hintText,
    required this.controller,
    this.validator,
    this.onChanged,
    this.obscureText = false,
    this.suffixIcon,
    this.iconColor = Colors.black54,
    this.width,
    this.height = 48,
    this.borderRadius = 20,
    this.backgroundColor = Colors.white,
    this.hintTextStyle,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      width: width,
      height: height,
      decoration: BoxDecoration(
        color: backgroundColor,
        borderRadius: BorderRadius.circular(borderRadius),
      ),
      child: Padding(
        padding: EdgeInsets.fromLTRB(15, 0, 0, 4),
        child: Row(
          mainAxisSize: MainAxisSize.max,
          children: [
            icon,
            Expanded(
              child: Padding(
                padding: EdgeInsets.fromLTRB(15, 0, 20, 0),
                child: TextFormField(
                  cursorColor: Theme.of(context).primaryColor,
                  controller: controller,
                  obscureText: obscureText,
                  validator: validator,
                  onChanged: onChanged,
                  decoration: InputDecoration(
                    fillColor: Colors.white,
                    focusColor: Colors.white,
                    hoverColor: Colors.white,
                    hintText: hintText,
                    hintStyle: hintTextStyle != null
                        ? hintTextStyle
                        : TextStyle(
                            fontSize: 13,
                            fontWeight: FontWeight.w500,
                          ),
                    suffixIcon: suffixIcon,
                    enabledBorder: UnderlineInputBorder(
                      borderSide: BorderSide(
                        color: Colors.transparent,
                        width: 1,
                      ),
                      borderRadius: const BorderRadius.only(
                        topLeft: Radius.circular(4.0),
                        topRight: Radius.circular(4.0),
                      ),
                    ),
                    focusedBorder: UnderlineInputBorder(
                      borderSide: BorderSide(
                        color: Colors.transparent,
                        width: 1,
                      ),
                      borderRadius: const BorderRadius.only(
                        topLeft: Radius.circular(4.0),
                        topRight: Radius.circular(4.0),
                      ),
                    ),
                  ),
                  style: GoogleFonts.poppins(
                    fontSize: 14,
                    fontWeight: FontWeight.w600,
                    color: Colors.black87,
                  ),
                ),
              ),
            )
          ],
        ),
      ),
    );
  }
}
