import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class DropdownController {
  String? selectedValue;
}

class Dropdown extends StatefulWidget {
  final String? name;
  final items;
  final DropdownController dropdownController;
  final Function? onChanged;
  final String? initialValue;

  Dropdown({
    Key? key,
    this.name,
    this.items,
    required this.dropdownController,
    this.onChanged,
    this.initialValue,
  }) : super(key: key) {
    if (initialValue != null && dropdownController.selectedValue == null)
      dropdownController.selectedValue = initialValue;
  }

  @override
  _DropdownState createState() => _DropdownState();
}

class _DropdownState extends State<Dropdown> {
  @override
  Widget build(BuildContext context) {
    return Container(
      child: DropdownButton<String>(
        value: (widget.dropdownController.selectedValue?.length ?? 0) > 0
            ? widget.dropdownController.selectedValue
            : null,
        icon: Icon(Icons.arrow_downward),
        iconSize: 24,
        elevation: 16,
        style: TextStyle(color: Colors.black),
        isExpanded: true,
        underline: Container(
          height: 2,
          color: Theme.of(context).primaryColor,
        ),
        onChanged: (String? newValue) {
          setState(() {
            widget.dropdownController.selectedValue = newValue;
          });
          if (widget.onChanged != null) {
            if (widget.onChanged != null) widget.onChanged!(newValue);
          }
        },
        items: widget.items.map<DropdownMenuItem<String>>((String value) {
          return DropdownMenuItem<String>(
            value: value,
            child: Text(value),
          );
        }).toList(),
      ),
    );
  }
}
