import 'package:ecom_widgets/models/slide.dart';
import 'package:ecom_widgets/widgets/platform_adaptor.dart';
import 'package:flutter/material.dart';

import 'package:ecom_widgets/widgets/custom_text_form_field.dart';
import 'package:ecom_widgets/widgets/platform_adaptor.dart';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:carousel_slider/carousel_slider.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:mvc_pattern/mvc_pattern.dart';
import 'package:responsive_grid/responsive_grid.dart';

class HeroComponent extends StatelessWidget {
  final Function(String text) onChangeFilterText;
  final List<Slide> slides;

  final bool isScrolledEnough;
  final setState;
  HeroComponent({
    Key? key,
    required Function(String text) this.onChangeFilterText,
    this.slides = const [],
    bool this.isScrolledEnough = false,
    this.setState,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    bool isWidescreen = PlatformType.of(context).isWideScreen();
    return Container(
      // color: Color(0xFFFAFAFA),
      height: MediaQuery.of(context).size.height - 90,
      width: MediaQuery.of(context).size.width,
      child: Stack(
        fit: StackFit.passthrough,
        children: [
          Align(
            alignment: Alignment.bottomCenter,
            child: FittedBox(
              child: Image.asset(
                'images/grocery.png',
                fit: BoxFit.cover,
                height: MediaQuery.of(context).size.height - 90,
                width: MediaQuery.of(context).size.width,
              ),
            ),
          ),
          if (slides.length != 0)
            CarouselSlider(
              options: CarouselOptions(
                autoPlay: true,
                autoPlayInterval: Duration(seconds: 5),
                height: MediaQuery.of(context).size.height,
                viewportFraction: SettingsAdaptor(
                  context: context,
                  narrowLayout: 1.0,
                  wideLayout: 1.0,
                ),
                onPageChanged: (index, reason) {
                  if (!isScrolledEnough) setState(() {});
                },
              ),
              items: slides.map((Slide slide) {
                return Builder(builder: (BuildContext context) {
                  return Container(
                    width: double.infinity,
                    height: double.infinity,
                    child: Stack(
                      children: [
                        Container(
                          width: double.infinity,
                          height: double.infinity,
                          child: CachedNetworkImage(
                            fit: BoxFit.cover,
                            imageUrl: '${slide.image}',
                          ),
                        ),
                        Container(
                          width: double.infinity,
                          height: double.infinity,
                          child: Column(
                            mainAxisAlignment: MainAxisAlignment.center,
                            crossAxisAlignment: CrossAxisAlignment.center,
                            children: [
                              Padding(
                                padding: const EdgeInsets.all(8.0),
                                child: Text(
                                  "${slide.text}",
                                  style: Theme.of(context)
                                      .textTheme
                                      .headline1!
                                      .merge(
                                        GoogleFonts.poppins(
                                          textStyle: TextStyle(
                                            color: Colors.black,
                                            fontSize: 48,
                                            fontWeight: FontWeight.bold,
                                          ),
                                        ),
                                      ),
                                ),
                              ),
                              SizedBox(height: 15),
                              Padding(
                                padding: const EdgeInsets.all(8.0),
                                child: Text(
                                  "${slide.subTitle}",
                                  style: Theme.of(context)
                                      .textTheme
                                      .subtitle1!
                                      .merge(
                                        TextStyle(
                                          color: Colors.grey[600],
                                          fontSize: 18,
                                          fontWeight: FontWeight.w100,
                                        ),
                                      ),
                                ),
                              ),
                              SizedBox(height: (75 + 48.0)),
                            ],
                          ),
                        ),
                      ],
                    ),
                  );
                });
              }).toList(),
            )
          else
            Container(),
          Align(
            alignment: Alignment.center,
            child: Container(
              child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  Padding(
                    padding: const EdgeInsets.all(8.0),
                    child: Text(
                      "",
                      style: Theme.of(context).textTheme.headline1!.merge(
                            GoogleFonts.poppins(
                              textStyle: TextStyle(
                                color: Colors.black,
                                fontSize: 48,
                                fontWeight: FontWeight.bold,
                              ),
                            ),
                          ),
                    ),
                  ),
                  SizedBox(height: 15),
                  Padding(
                    padding: const EdgeInsets.all(8.0),
                    child: Text(
                      "",
                      style: Theme.of(context).textTheme.subtitle1!.merge(
                            TextStyle(
                              color: Colors.grey[600],
                              fontSize: 18,
                              fontWeight: FontWeight.w100,
                            ),
                          ),
                    ),
                  ),
                  SizedBox(height: 75),
                  HeroSearchWidget(
                    onChangeFilterText: onChangeFilterText,
                  ),
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }
}

class HeroSearchWidget extends StatefulWidget {
  final Function(String text) onChangeFilterText;

  final bool removeShadow;
  final bool resizeOnPlatformChange;
  final bool addBorder;

  HeroSearchWidget({
    Key? key,
    required Function(String text) this.onChangeFilterText,
    bool this.removeShadow = false,
    bool this.addBorder = false,
    this.resizeOnPlatformChange = false,
  }) : super(key: key);

  @override
  _HeroSearchWidgetState createState() => _HeroSearchWidgetState();
}

class _HeroSearchWidgetState extends State<HeroSearchWidget> {
  TextEditingController searchController = TextEditingController();

  onPressedSearch() {
    widget.onChangeFilterText(searchController.text);
  }

  @override
  Widget build(BuildContext context) {
    bool isWidescreen = PlatformType.of(context).isWideScreen();

    bool forceResizeLower = widget.resizeOnPlatformChange;
    bool forceResizeLowest =
        PlatformType.of(context).isTablet() && widget.resizeOnPlatformChange;
    return Container(
      width: widget.resizeOnPlatformChange ? double.infinity : 600,
      decoration: widget.removeShadow
          ? BoxDecoration(
              border: Border.all(color: Colors.grey[300]!),
            )
          : BoxDecoration(boxShadow: [
              BoxShadow(
                color: Colors.grey[300]!,
                offset: Offset(0, 2),
                blurRadius: 30,
                spreadRadius: 10,
              )
            ]),
      child: ResponsiveGridRow(children: [
        ResponsiveGridCol(
          xl: forceResizeLower ? 8 : 9,
          lg: forceResizeLower ? 7 : 9,
          md: forceResizeLower ? 7 : 9,
          sm: forceResizeLower ? 7 : 9,
          xs: 8,
          child: CustomTextFormField(
            icon: Container(),
            hintText: "Search your products from here",
            hintTextStyle: Theme.of(context).textTheme.bodyText1!.merge(
                  GoogleFonts.ubuntu(
                    color: Colors.grey[600],
                  ),
                ),
            borderRadius: 2,
            controller: searchController,
          ),
        ),
        ResponsiveGridCol(
          xl: forceResizeLower ? 4 : 3,
          lg: forceResizeLower ? 5 : 3,
          md: forceResizeLower ? 5 : 3,
          sm: forceResizeLower ? 5 : 3,
          xs: 4,
          child: ElevatedButton.icon(
            onPressed: onPressedSearch,
            style: ElevatedButton.styleFrom(
              padding: EdgeInsets.only(
                top: 20,
                bottom: 20,
                left: 20,
                right: 20,
              ),
              primary: Theme.of(context).primaryColor,
            ),
            icon: Icon(
              Icons.search_outlined,
              color: Colors.white,
            ),
            label: Center(
              child: Text(
                "Search",
                style: Theme.of(context).textTheme.headline1!.merge(
                      TextStyle(
                        color: Colors.white,
                        fontSize: 17,
                        fontWeight: FontWeight.w100,
                      ),
                    ),
              ),
            ),
          ),
        ),
      ]),
    );
  }
}
