import 'dart:async';

import 'package:flutter/material.dart';
import 'package:geolocator/geolocator.dart';
import 'package:get/get.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';

import 'loading.dart';

class LocationPicker extends StatefulWidget {
  final String initialLatitude;
  final String initialLongitude;
  LocationPicker({
    Key? key,
    this.initialLatitude = "0",
    this.initialLongitude = "0",
  }) : super(key: key);

  @override
  _LocationPickerState createState() => _LocationPickerState();
}

class _LocationPickerState extends State<LocationPicker> {
  Completer<GoogleMapController> _controller = Completer();
  late LatLng userPosition;
  var isCheck = false;
  bool isLoad = true;
  late Function updateLocation;

  setLocation() async {
    final Position position = await Geolocator.getCurrentPosition();
    userPosition = LatLng(position.latitude, position.longitude);
    isLoad = false;
    setState(() {});
  }

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    userPosition = LatLng(
      double.parse(widget.initialLatitude),
      double.parse(widget.initialLatitude),
    );
  }

  @override
  Widget build(BuildContext context) {
    if (!isCheck) {
      isCheck = true;
      updateLocation = ModalRoute.of(context)!.settings.arguments! as Function;
      setLocation();
    }

    return Scaffold(
      body: isLoad
          ? Loading()
          : Stack(
              children: [
                GoogleMap(
                  onTap: (val) async {
                    setState(() {
                      userPosition = LatLng(val.latitude, val.longitude);
                    });
                    updateLocation(
                      userPosition.latitude.toString(),
                      userPosition.longitude.toString(),
                    );
                  },
                  markers: {
                    Marker(
                      markerId: MarkerId("marker"),
                      position: userPosition,
                      draggable: true,
                    ),
                  },
                  mapToolbarEnabled: false,
                  zoomControlsEnabled: false,
                  initialCameraPosition:
                      CameraPosition(target: userPosition, zoom: 18),
                  onMapCreated: (GoogleMapController controller) {
                    _controller.complete(controller);
                  },
                ),
                Align(
                  alignment: Alignment.bottomCenter,
                  child: Container(
                    margin: EdgeInsets.only(bottom: 16),
                    child: Padding(
                      padding: EdgeInsets.symmetric(
                        vertical: 10,
                        horizontal: 30,
                      ),
                      child: ElevatedButton(
                        onPressed: () {
                          updateLocation(
                            userPosition.latitude.toString(),
                            userPosition.longitude.toString(),
                          );
                          Navigator.pop(context);
                        },
                        child: Text(
                          "Select Location",
                          style: TextStyle(
                            color: Colors.white,
                            fontSize: 20,
                          ),
                        ),
                        style: ElevatedButton.styleFrom(
                          minimumSize: Size(50, 50),
                          primary: Theme.of(context).primaryColor,
                          shape: RoundedRectangleBorder(
                            borderRadius: BorderRadius.circular(10.0),
                          ),
                        ),
                      ),
                    ),
                  ),
                )
              ],
            ),
    );
  }
}
