import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:persistent_bottom_nav_bar/persistent-tab-view.dart';

import 'location_picker.dart';

/// Google maps location widget.
class LocationField extends StatefulWidget {
  final String label;
  final IconData icon;
  final LocationFieldController? controller;

  LocationField({
    Key? key,
    this.label = "Select Location",
    this.icon = Icons.location_pin,
    required this.controller,
  }) : super(key: key);

  @override
  _LocationFieldState createState() => _LocationFieldState();
}

class _LocationFieldState extends State<LocationField> {
  @override
  Widget build(BuildContext context) {
    print(widget.controller!.latitude);
    return Container(
      decoration: BoxDecoration(
        border: Border.all(color: Colors.grey),
        borderRadius: BorderRadius.all(
          Radius.circular(5),
        ),
        color: Colors.white,
      ),
      child: ClipRRect(
        borderRadius: BorderRadius.all(
          Radius.circular(5),
        ),
        child: Material(
          color: Colors.transparent,
          child: InkWell(
            onTap: () async {
              await pushNewScreenWithRouteSettings(context,
                  screen: LocationPicker(),
                  settings: RouteSettings(
                      arguments: widget.controller!.updateLocation));
              setState(() {});
            },
            child: Padding(
              padding: EdgeInsets.symmetric(vertical: 10, horizontal: 10),
              child: Row(
                children: [
                  Icon(widget.icon),
                  SizedBox(
                    width: 16,
                  ),
                  Expanded(
                    child: Text(
                      widget.controller!.latitude == "0"
                          ? widget.label
                          : "${widget.controller!.latitude}, ${widget.controller!.longitude}",
                      style: GoogleFonts.lato(
                        fontSize: 15,
                        fontWeight: FontWeight.w600,
                      ),
                      textAlign: TextAlign.start,
                      maxLines: 1,
                      overflow: TextOverflow.ellipsis,
                    ),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}

class LocationFieldController {
  String latitude = "0";
  String longitude = "0";

  isApplied() {
    return latitude != "0" && longitude != "0";
  }

  updateLocation(String tLatitude, String tLongitude) {
    latitude = tLatitude;
    longitude = tLongitude;

    print(latitude + ", " + longitude);
    //widget.setState(() {});
  }
}
