import 'package:ecom_widgets/widgets/loading.dart';
import 'package:flutter/material.dart';

const mobileBreakpoint = 768;
const tabletBreakpoint = 1024;
const widescreenBreakPoint = 1500;

PlatformAdaptor({
  loading: false,
  required Function narrowLayout,
  required Function wideLayout,
}) {
  return Scaffold(
    body: LayoutBuilder(
      builder: (context, constraints) {
        if (loading) return Loading();

        if (constraints.maxWidth < mobileBreakpoint)
          return narrowLayout();
        else
          return wideLayout();
      },
    ),
  );
}

PlatformWidgetAdaptor(
    {loading: false,
    required Function narrowLayout,
    required Function wideLayout}) {
  return LayoutBuilder(
    builder: (context, constraints) {
      if (loading) return Loading();

      double width = MediaQuery.of(context).size.width;

      if (width < mobileBreakpoint)
        return narrowLayout();
      else
        return wideLayout();
    },
  );
}

Widget WidgetAdaptor({
  loading: false,
  required Widget narrowLayout,
  required Widget wideLayout,
  required double breakPoint,
}) {
  return LayoutBuilder(
    builder: (context, constraints) {
      if (loading) return Loading();

      if (constraints.maxWidth < breakPoint)
        return narrowLayout;
      else
        return wideLayout;
    },
  );
}

dynamic SettingsAdaptor({
  required BuildContext context,
  dynamic narrowLayout,
  dynamic wideLayout,
  bool isCallable: false,
}) {
  double width = MediaQuery.of(context).size.width;

  if (width < mobileBreakpoint)
    return isCallable ? narrowLayout() : narrowLayout;
  else
    return isCallable ? wideLayout() : wideLayout;
}

class PlatformType {
  BuildContext context;

  PlatformType.of(this.context);

  bool isMobile() {
    return MediaQuery.of(context).size.width < mobileBreakpoint;
  }

  bool isTablet() {
    return (MediaQuery.of(context).size.width >= mobileBreakpoint &&
        MediaQuery.of(context).size.width < tabletBreakpoint);
  }

  bool isDesktop() {
    return !isTablet() && !isMobile();
  }

  bool isWideScreen() {
    return MediaQuery.of(context).size.width >= widescreenBreakPoint;
  }
}
